==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ProfileEnrollmentPolicyRule.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LifecycleStatus;
import com.okta.sdk.resource.model.PolicyLinks;
import com.okta.sdk.resource.model.PolicyRule;
import com.okta.sdk.resource.model.PolicyRuleType;
import com.okta.sdk.resource.model.ProfileEnrollmentPolicyRuleActions;
import java.time.OffsetDateTime;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ProfileEnrollmentPolicyRule
 */
@JsonPropertyOrder({ ProfileEnrollmentPolicyRule.JSON_PROPERTY_ACTIONS,
        ProfileEnrollmentPolicyRule.JSON_PROPERTY_CONDITIONS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "type", visible = true, defaultImpl = ProfileEnrollmentPolicyRule.class)

public class ProfileEnrollmentPolicyRule extends PolicyRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACTIONS = "actions";
    private ProfileEnrollmentPolicyRuleActions actions;

    public static final String JSON_PROPERTY_CONDITIONS = "conditions";
    private JsonNullable<String> conditions = JsonNullable.<String> undefined();

    public ProfileEnrollmentPolicyRule() {
    }

    /*
     * @JsonCreator public ProfileEnrollmentPolicyRule(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated ) { this(); this.created = created;
     * this.lastUpdated = lastUpdated; }
     */

    public ProfileEnrollmentPolicyRule actions(ProfileEnrollmentPolicyRuleActions actions) {

        this.actions = actions;
        return this;
    }

    /**
     * Get actions
     *
     * @return actions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ProfileEnrollmentPolicyRuleActions getActions() {
        return actions;
    }

    @JsonProperty(JSON_PROPERTY_ACTIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setActions(ProfileEnrollmentPolicyRuleActions actions) {
        this.actions = actions;
    }

    public ProfileEnrollmentPolicyRule conditions(String conditions) {
        this.conditions = JsonNullable.<String> of(conditions);

        return this;
    }

    /**
     * Policy Rule conditions aren&#39;t supported for this policy type
     *
     * @return conditions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Policy Rule conditions aren't supported for this policy type")
    @JsonIgnore

    public String getConditions() {
        return conditions.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<String> getConditions_JsonNullable() {
        return conditions;
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    public void setConditions_JsonNullable(JsonNullable<String> conditions) {
        this.conditions = conditions;
    }

    public void setConditions(String conditions) {
        this.conditions = JsonNullable.<String> of(conditions);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRule profileEnrollmentPolicyRule = (ProfileEnrollmentPolicyRule) o;
        return Objects.equals(this.actions, profileEnrollmentPolicyRule.actions)
                && equalsNullable(this.conditions, profileEnrollmentPolicyRule.conditions);
        // && super.equals(o);
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(actions, hashCodeNullable(conditions), super.hashCode());
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRule {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    actions: ").append(toIndentedString(actions)).append("\n");
        sb.append("    conditions: ").append(toIndentedString(conditions)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ProfileEnrollmentPolicyRule.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LifecycleStatus;
import com.okta.sdk.resource.model.PolicyLinks;
import com.okta.sdk.resource.model.PolicyRule;
import com.okta.sdk.resource.model.PolicyRuleType;
import com.okta.sdk.resource.model.ProfileEnrollmentPolicyRuleActions;
import java.time.OffsetDateTime;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ProfileEnrollmentPolicyRule
 */
@JsonPropertyOrder({ ProfileEnrollmentPolicyRule.JSON_PROPERTY_ACTIONS,
        ProfileEnrollmentPolicyRule.JSON_PROPERTY_CONDITIONS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "type", visible = true, defaultImpl = ProfileEnrollmentPolicyRule.class)

public class ProfileEnrollmentPolicyRule extends PolicyRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ACTIONS = "actions";
    private ProfileEnrollmentPolicyRuleActions actions;

    public static final String JSON_PROPERTY_CONDITIONS = "conditions";
    private JsonNullable<String> conditions = JsonNullable.<String> undefined();

    public ProfileEnrollmentPolicyRule() {
    }

    /*
     * @JsonCreator public ProfileEnrollmentPolicyRule(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated ) { this(); this.created = created;
     * this.lastUpdated = lastUpdated; }
     */

    public ProfileEnrollmentPolicyRule actions(ProfileEnrollmentPolicyRuleActions actions) {

        this.actions = actions;
        return this;
    }

    /**
     * Get actions
     *
     * @return actions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ProfileEnrollmentPolicyRuleActions getActions() {
        return actions;
    }

    @JsonProperty(JSON_PROPERTY_ACTIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setActions(ProfileEnrollmentPolicyRuleActions actions) {
        this.actions = actions;
    }

    public ProfileEnrollmentPolicyRule conditions(String conditions) {
        this.conditions = JsonNullable.<String> of(conditions);

        return this;
    }

    /**
     * Policy Rule conditions aren&#39;t supported for this policy type
     *
     * @return conditions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Policy Rule conditions aren't supported for this policy type")
    @JsonIgnore

    public String getConditions() {
        return conditions.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<String> getConditions_JsonNullable() {
        return conditions;
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    public void setConditions_JsonNullable(JsonNullable<String> conditions) {
        this.conditions = conditions;
    }

    public void setConditions(String conditions) {
        this.conditions = JsonNullable.<String> of(conditions);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRule profileEnrollmentPolicyRule = (ProfileEnrollmentPolicyRule) o;
        return Objects.equals(this.actions, profileEnrollmentPolicyRule.actions)
                && equalsNullable(this.conditions, profileEnrollmentPolicyRule.conditions);
        // && super.equals(o);
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(actions, hashCodeNullable(conditions), super.hashCode());
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRule {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    actions: ").append(toIndentedString(actions)).append("\n");
        sb.append("    conditions: ").append(toIndentedString(conditions)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
